@@ -1,7 +1,7 @@
 #ifndef MESSAGE_H
 #define MESSAGE_H
 
-static SOCKET_DAEMON_HANDLER(message_handler);
 void handle_message(FILE *rsp, char *message);
+bool message_loop_begin(char *socket_path);
 
 #endif
