@@ -113,14 +113,14 @@ enum mouse_drop_action mouse_determine_drop_action(struct mouse_state *ms, struc
     return MOUSE_DROP_ACTION_NONE;
 }
 
-void mouse_drop_action_stack(struct space_manager *sm, struct window_manager *wm, struct view *src_view, struct window *src_window, struct view *dst_view, struct window *dst_window)
+void mouse_drop_action_stack(struct window_manager *wm, struct view *src_view, struct window *src_window, struct view *dst_view, struct window *dst_window)
 {
-    space_manager_untile_window(sm, src_view, src_window);
+    space_manager_untile_window(src_view, src_window);
     window_manager_remove_managed_window(wm, src_window->id);
 
     struct window_node *dst_node = view_find_window_node(dst_view, dst_window->id);
     if (dst_node->window_count+1 < NODE_MAX_WINDOW_COUNT) {
-        view_stack_window_node(dst_view, dst_node, src_window);
+        view_stack_window_node(dst_node, src_window);
         window_manager_add_managed_window(wm, src_window, dst_view);
         window_manager_adjust_layer(src_window, LAYER_BELOW);
         scripting_addition_order_window(src_window->id, 1, dst_node->window_order[1]);
@@ -161,7 +161,7 @@ void mouse_drop_action_swap(struct window_manager *wm, struct view *src_view, st
     window_manager_animate_window_list(window_list, ts_buf_len(window_list));
 }
 
-void mouse_drop_action_warp(struct space_manager *sm, struct window_manager *wm, struct view *src_view, struct window_node *src_node, struct window *src_window, struct view *dst_view, struct window_node *dst_node, struct window *dst_window, enum window_node_split split, enum window_node_child child)
+void mouse_drop_action_warp(struct window_manager *wm, struct view *src_view, struct window_node *src_node, struct window *src_window, struct view *dst_view, struct window_node *dst_node, struct window *dst_window, enum window_node_split split, enum window_node_child child)
 {
     if ((src_node->parent && dst_node->parent) &&
         (src_node->parent == dst_node->parent) &&
@@ -203,7 +203,7 @@ void mouse_drop_no_target(struct space_manager *sm, struct window_manager *wm, s
     if (src_view->sid == dst_view->sid) {
         window_node_flush(node);
     } else {
-        space_manager_untile_window(sm, src_view, window);
+        space_manager_untile_window(src_view, window);
         window_manager_remove_managed_window(wm, window->id);
         window_manager_purify_window(wm, window);
 
