@@ -27,9 +27,9 @@
 #include "common.h"
 
 #ifdef __x86_64__
-#include "x86_64/payload.m"
+#include "x64_payload.m"
 #elif __arm64__
-#include "arm64/payload.m"
+#include "arm64_payload.m"
 #include <ptrauth.h>
 #endif
 
@@ -255,10 +255,6 @@ static bool verify_os_version(NSOperatingSystemVersion os_version)
     return false;
 }
 
-#ifdef __x86_64__
-static double animation_time = 0.0001;
-#endif
-
 static void init_instances()
 {
     NSOperatingSystemVersion os_version = [[NSProcessInfo processInfo] operatingSystemVersion];
@@ -377,7 +373,7 @@ static void init_instances()
         NSLog(@"[yabai-sa] (0x%llx) animation_time_addr found at address 0x%llX (0x%llx)", baseaddr, animation_time_addr, animation_time_addr - baseaddr);
         if (vm_protect(mach_task_self(), page_align(animation_time_addr), vm_page_size, 0, VM_PROT_READ | VM_PROT_WRITE | VM_PROT_COPY) == KERN_SUCCESS) {
 #ifdef __x86_64__
-            *(uint32_t *)(animation_time_addr + 4) = (uint32_t)((uint64_t)&animation_time - (animation_time_addr + 8));
+            *(uint64_t *) animation_time_addr = 0x660fefc0660fefc0;
 #elif __arm64__
             *(uint32_t *) animation_time_addr = 0x2f00e400;
 #endif
