@@ -133,10 +133,18 @@ static inline enum window_node_child window_node_get_child(struct window_node *n
     return node->child != CHILD_NONE ? node->child : g_space_manager.window_placement;
 }
 
-static inline enum window_node_split window_node_get_split(struct window_node *node)
+static inline enum window_node_split window_node_get_split(struct view *view, struct window_node *node)
 {
-    if (node->split                != SPLIT_NONE) return node->split;
-    if (g_space_manager.split_type != SPLIT_AUTO) return g_space_manager.split_type;
+    if (node->split != SPLIT_NONE) return node->split;
+
+    if (view->split_type != SPLIT_NONE) {
+        if (view->split_type != SPLIT_AUTO) {
+            return view->split_type;
+        }
+    } else if (g_space_manager.split_type != SPLIT_AUTO) {
+        return g_space_manager.split_type;
+    }
+
     return node->area.w >= node->area.h ? SPLIT_Y : SPLIT_X;
 }
 
@@ -153,25 +161,31 @@ static inline int window_node_get_gap(struct view *view)
 static void area_make_pair(enum window_node_split split, int gap, float ratio, struct area *parent_area, struct area *left_area, struct area *right_area)
 {
     if (split == SPLIT_Y) {
-        *left_area = *parent_area;
-        left_area->w = (int)((parent_area->w - gap) * ratio);
-
+        *left_area  = *parent_area;
         *right_area = *parent_area;
-        right_area->x += (left_area->w + gap);
-        right_area->w = (int)((parent_area->w - gap) * (1 - ratio));
+
+        float left_width  = (parent_area->w - gap) * ratio;
+        float right_width = (parent_area->w - gap) * (1 - ratio);
+
+        left_area->w   = (int)left_width;
+        right_area->w  = (int)right_width;
+        right_area->x += (int)(left_width + 0.5f) + gap;
     } else {
-        *left_area = *parent_area;
-        left_area->h = (int)((parent_area->h - gap) * ratio);
-
+        *left_area  = *parent_area;
         *right_area = *parent_area;
-        right_area->y += (left_area->h + gap);
-        right_area->h = (int)((parent_area->h - gap) * (1 - ratio));
+
+        float left_width  = (parent_area->h - gap) * ratio;
+        float right_width = (parent_area->h - gap) * (1 - ratio);
+
+        left_area->h   = (int)left_width;
+        right_area->h  = (int)right_width;
+        right_area->y += (int)(left_width + 0.5f) + gap;
     }
 }
 
 static void area_make_pair_for_node(struct view *view, struct window_node *node)
 {
-    enum window_node_split split = window_node_get_split(node);
+    enum window_node_split split = window_node_get_split(view, node);
     float ratio = window_node_get_ratio(node);
     int gap     = window_node_get_gap(view);
 
@@ -704,8 +718,8 @@ struct window_node *view_remove_window_node(struct view *view, struct window *wi
     free(child);
     free(node);
 
-    if (view->auto_balance) {
-        window_node_balance(view->root, SPLIT_X | SPLIT_Y);
+    if (view->auto_balance != SPLIT_NONE) {
+        window_node_balance(view->root, view->auto_balance);
         view_update(view);
         return view->root;
     }
@@ -768,13 +782,22 @@ struct window_node *view_add_window_node_with_insertion_point(struct view *view,
             }
         }
 
-        if (!leaf) leaf = view_find_window_node(view, g_window_manager.focused_window_id);
-        if (!leaf) leaf = view_find_min_depth_leaf_node(view->root);
+        if (!leaf) {
+            if (g_space_manager.window_insertion_point == INSERT_FOCUSED) {
+                leaf = view_find_window_node(view, g_window_manager.focused_window_id);
+            } else if (g_space_manager.window_insertion_point == INSERT_FIRST) {
+                leaf = window_node_find_first_leaf(view->root);
+            } else if (g_space_manager.window_insertion_point == INSERT_LAST) {
+                leaf = window_node_find_last_leaf(view->root);
+            }
+
+            if (!leaf) leaf = view_find_min_depth_leaf_node(view->root);
+        }
 
         window_node_split(view, leaf, window);
 
-        if (view->auto_balance) {
-            window_node_balance(view->root, SPLIT_X | SPLIT_Y);
+        if (view->auto_balance != SPLIT_NONE) {
+            window_node_balance(view->root, view->auto_balance);
             view_update(view);
             return view->root;
         }
@@ -982,6 +1005,7 @@ struct view *view_create(uint64_t sid)
         if (!view_check_flag(view, VIEW_RIGHT_PADDING))  view->right_padding  = g_space_manager.right_padding;
         if (!view_check_flag(view, VIEW_WINDOW_GAP))     view->window_gap     = g_space_manager.window_gap;
         if (!view_check_flag(view, VIEW_AUTO_BALANCE))   view->auto_balance   = g_space_manager.auto_balance;
+        if (!view_check_flag(view, VIEW_SPLIT_TYPE))     view->split_type     = g_space_manager.split_type;
         view_update(view);
     } else {
         view->layout = VIEW_FLOAT;
@@ -990,6 +1014,21 @@ struct view *view_create(uint64_t sid)
     return view;
 }
 
+void view_destroy(struct view *view)
+{
+    if (view->root) {
+        if (view->root->left)  window_node_destroy(view->root->left);
+        if (view->root->right) window_node_destroy(view->root->right);
+
+        for (int i = 0; i < view->root->window_count; ++i) {
+            window_manager_remove_managed_window(&g_window_manager, view->root->window_list[i]);
+        }
+
+        insert_feedback_destroy(view->root);
+        memset(view->root, 0, sizeof(struct window_node));
+    }
+}
+
 void view_clear(struct view *view)
 {
     if (view->root) {
